@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from urllib3.exceptions import ProtocolError
-
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class Deployment(NamespacedResource):
     """
     OpenShift Deployment object.
@@ -26,7 +29,7 @@ class Deployment(NamespacedResource):
         body = super().to_dict()
         body.update({"spec": {"replicas": replica_count}})
 
-        self.logger.info(f"Set deployment replicas: {replica_count}")
+        LOGGER.info(f"Set deployment replicas: {replica_count}")
         return self.update(resource_dict=body)
 
     def wait_for_replicas(self, deployed=True, timeout=TIMEOUT):
@@ -40,12 +43,12 @@ class Deployment(NamespacedResource):
         Raises:
             TimeoutExpiredError: If not availableReplicas is equal to replicas.
         """
-        self.logger.info(f"Wait for {self.kind} {self.name} to be deployed: {deployed}")
+        LOGGER.info(f"Wait for {self.kind} {self.name} to be deployed: {deployed}")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions=ProtocolError,
-            func=self.api().get,
+            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
         )
         for sample in samples:
