@@ -2,6 +2,7 @@ import re
 
 from openshift.dynamic.exceptions import ConflictError
 
+from ocp_resources.logger import get_logger
 from ocp_resources.node_network_configuration_enactment import (
     NodeNetworkConfigurationEnactment,
 )
@@ -10,6 +11,9 @@ from ocp_resources.resource import Resource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class NNCPConfigurationFailed(Exception):
     pass
 
@@ -32,7 +36,7 @@ class NodeNetworkConfigurationPolicy(Resource):
 
     def __init__(
         self,
-        name,
+        name=None,
         client=None,
         worker_pods=None,
         node_selector=None,
@@ -41,11 +45,13 @@ class NodeNetworkConfigurationPolicy(Resource):
         ports=None,
         ipv4_enable=False,
         ipv4_dhcp=False,
+        ipv4_auto_dns=True,
         ipv4_addresses=None,
         ipv6_enable=False,
         node_active_nics=None,
         dns_resolver=None,
         routes=None,
+        yaml_file=None,
     ):
         """
         ipv4_addresses should be sent in this format:
@@ -56,7 +62,9 @@ class NodeNetworkConfigurationPolicy(Resource):
          {"ip": "10.4.5.6", "prefix-length": 24},
          {"ip": "10.7.8.9", "prefix-length": 23}]
         """
-        super().__init__(name=name, client=client, teardown=teardown)
+        super().__init__(
+            name=name, client=client, teardown=teardown, yaml_file=yaml_file
+        )
         self.desired_state = {"interfaces": []}
         self.worker_pods = worker_pods
         self.mtu = mtu
@@ -67,6 +75,7 @@ class NodeNetworkConfigurationPolicy(Resource):
         self.node_active_nics = node_active_nics or []
         self.ipv4_enable = ipv4_enable
         self._ipv4_dhcp = ipv4_dhcp
+        self.ipv4_auto_dns = ipv4_auto_dns
         self.ipv4_addresses = ipv4_addresses or []
         self.ipv6_enable = ipv6_enable
         self.ipv4_iface_state = {}
@@ -92,7 +101,7 @@ class NodeNetworkConfigurationPolicy(Resource):
         interfaces = [
             iface
             for iface in self.desired_state["interfaces"]
-            if not (iface["name"] == interface["name"])
+            if iface["name"] != interface["name"]
         ]
         # Add the interface
         interfaces.append(interface)
@@ -100,6 +109,9 @@ class NodeNetworkConfigurationPolicy(Resource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         if self.dns_resolver or self.routes or self.iface:
             res.setdefault("spec", {}).setdefault("desiredState", {})
 
@@ -119,7 +131,11 @@ class NodeNetworkConfigurationPolicy(Resource):
             is a valid desired state and therefore not blocked in the code, but nmstate would
             reject it. Such configuration might be used for negative tests.
             """
-            self.iface["ipv4"] = {"enabled": self.ipv4_enable, "dhcp": self.ipv4_dhcp}
+            self.iface["ipv4"] = {
+                "enabled": self.ipv4_enable,
+                "dhcp": self.ipv4_dhcp,
+                "auto-dns": self.ipv4_auto_dns,
+            }
             if self.ipv4_addresses:
                 self.iface["ipv4"]["address"] = self.ipv4_addresses
 
@@ -138,11 +154,11 @@ class NodeNetworkConfigurationPolicy(Resource):
         samples = TimeoutSampler(
             wait_timeout=3,
             sleep=1,
-            exceptions=ConflictError,
+            exceptions_dict={ConflictError: []},
             func=self.update,
             resource_dict=resource,
         )
-        self.logger.info(f"Applying {resource}")
+        LOGGER.info(f"Applying {resource}")
         for _ in samples:
             return
 
@@ -156,7 +172,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                     mtu = pod.execute(
                         command=["cat", f"/sys/class/net/{port}/mtu"]
                     ).strip()
-                    self.logger.info(
+                    LOGGER.info(
                         f"Backup MTU: {pod.node.name} interface {port} MTU is {mtu}"
                     )
                     self.mtu_dict[port] = mtu
@@ -168,7 +184,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             self.validate_create()
             return self
         except Exception as e:
-            self.logger.error(e)
+            LOGGER.error(e)
             self.clean_up()
             raise
 
@@ -212,7 +228,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                 self.wait_for_status_success()
                 self.wait_for_interface_deleted()
             except Exception as e:
-                self.logger.error(e)
+                LOGGER.error(e)
 
         super().clean_up()
 
@@ -224,7 +240,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                     node_network_state = NodeNetworkState(name=pod.node.name)
                     iface_dict = node_network_state.get_interface(name=iface_name)
                     if iface_dict.get("type") == "ethernet":
-                        self.logger.info(f"{iface_name} is type ethernet, skipping.")
+                        LOGGER.info(f"{iface_name} is type ethernet, skipping.")
                         continue
 
                     node_network_state.wait_until_deleted(name=iface_name)
@@ -293,63 +309,39 @@ class NodeNetworkConfigurationPolicy(Resource):
             if condition["type"] == self.Conditions.Type.AVAILABLE:
                 return condition["reason"]
 
-    def wait_for_configuration_conditions_unknown_or_progressing(self, wait_timeout=30):
-        samples = TimeoutSampler(
-            wait_timeout=wait_timeout,
-            sleep=1,
-            func=lambda: self.instance.status.conditions,
-        )
-        for sample in samples:
-            if (
-                sample
-                and sample[0]["type"] == self.Conditions.Type.AVAILABLE
-                and (
-                    sample[0]["status"] == self.Condition.Status.UNKNOWN
-                    or sample[0]["reason"] == self.Conditions.Reason.CONFIGURING
-                )
-            ):
-                return sample
-
     def wait_for_status_success(self):
         failed_condition_reason = self.Conditions.Reason.FAILED
         no_match_node_condition_reason = self.Conditions.Reason.NO_MATCHING_NODE
-
-        def _process_failed_status():
-            last_err_msg = None
-            for failed_nnce in self._get_failed_nnce():
-                nnce_name = failed_nnce.instance.metadata.name
-                nnce_dict = failed_nnce.instance.to_dict()
-                for cond in nnce_dict["status"]["conditions"]:
-                    err_msg = self._get_nnce_error_msg(
-                        nnce_name=nnce_name, nnce_condition=cond
-                    )
-                    if err_msg:
-                        last_err_msg = err_msg
-
-            raise NNCPConfigurationFailed(
-                f"Reason: {failed_condition_reason}\n{last_err_msg}"
-            )
-
         # if we get here too fast there are no conditions, we need to wait.
-        self.wait_for_configuration_conditions_unknown_or_progressing()
+        self.wait_for_conditions()
 
         samples = TimeoutSampler(wait_timeout=480, sleep=1, func=self.status)
         try:
             for sample in samples:
                 if sample == self.Conditions.Reason.SUCCESS:
-                    self.logger.info(f"NNCP {self.name} configured Successfully")
+                    LOGGER.info(f"NNCP {self.name} configured Successfully")
                     return sample
 
-                elif sample == no_match_node_condition_reason:
+                if sample == no_match_node_condition_reason:
                     raise NNCPConfigurationFailed(
                         f"{self.name}. Reason: {no_match_node_condition_reason}"
                     )
 
-                elif sample == failed_condition_reason:
-                    _process_failed_status()
+                if sample == failed_condition_reason:
+                    for failed_nnce in self._get_failed_nnce():
+                        nnce_name = failed_nnce.instance.metadata.name
+                        nnce_dict = failed_nnce.instance.to_dict()
+                        for cond in nnce_dict["status"]["conditions"]:
+                            err_msg = self._get_nnce_error_msg(
+                                nnce_name=nnce_name, nnce_condition=cond
+                            )
+                            if err_msg:
+                                LOGGER.error(err_msg)
+
+                    raise NNCPConfigurationFailed(f"Reason: {failed_condition_reason}")
 
         except (TimeoutExpiredError, NNCPConfigurationFailed):
-            self.logger.error(
+            LOGGER.error(
                 f"Unable to configure NNCP {self.name} for node {self.node_selector}"
             )
             raise
@@ -379,7 +371,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             try:
                 nnce.wait_for_conditions()
             except TimeoutExpiredError:
-                self.logger.error(f"Failed to get NNCE {nnce.name} status")
+                LOGGER.error(f"Failed to get NNCE {nnce.name} status")
                 continue
 
             for nnce_cond in nnce.instance.status.conditions:
