@@ -2,11 +2,15 @@ import json
 
 import kubernetes
 
+from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutWatch
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class ExecOnPodError(Exception):
     def __init__(self, command, rc, out, err):
         self.cmd = command
@@ -32,11 +36,16 @@ class Pod(NamespacedResource):
     api_version = NamespacedResource.ApiVersion.V1
 
     class Status(NamespacedResource.Status):
-        RUNNING = "Running"
         CRASH_LOOPBACK_OFF = "CrashLoopBackOff"
 
     def __init__(
-        self, name, namespace, client=None, teardown=True, privileged_client=None
+        self,
+        name=None,
+        namespace=None,
+        client=None,
+        teardown=True,
+        privileged_client=None,
+        yaml_file=None,
     ):
         super().__init__(
             name=name,
@@ -44,6 +53,7 @@ class Pod(NamespacedResource):
             client=client,
             teardown=teardown,
             privileged_client=privileged_client,
+            yaml_file=yaml_file,
         )
         self._kube_api = kubernetes.client.CoreV1Api(api_client=self.client.client)
 
@@ -57,7 +67,7 @@ class Pod(NamespacedResource):
         """
         return self.instance.spec.containers
 
-    def execute(self, command, timeout=60, container=None):
+    def execute(self, command, timeout=60, container=None, ignore_rc=False):
         """
         Run command on Pod
 
@@ -65,6 +75,7 @@ class Pod(NamespacedResource):
             command (list): Command to run.
             timeout (int): Time to wait for the command.
             container (str): Container name where to exec the command.
+            ignore_rc (bool): If True ignore error rc from the shell and return out.
 
         Returns:
             str: Command output.
@@ -74,7 +85,7 @@ class Pod(NamespacedResource):
         """
         error_channel = {}
         stream_closed_error = "stream resp is closed"
-        self.logger.info(f"Execute {command} on {self.name} ({self.node.name})")
+        LOGGER.info(f"Execute {command} on {self.name} ({self.node.name})")
         resp = kubernetes.stream.stream(
             api_method=self._kube_api.connect_get_namespaced_pod_exec,
             name=self.name,
@@ -113,7 +124,7 @@ class Pod(NamespacedResource):
         stdout = resp.read_stdout(timeout=5)
         stderr = resp.read_stderr(timeout=5)
 
-        if rcstring == "Success":
+        if rcstring == "Success" or ignore_rc:
             return stdout
 
         if rcstring == "Failure":
